<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Editar destinatarios Forma");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Editar destinatarios Forma");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "forma Página");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Usted puede configurar más de un destinatario mediante la separación de los mensajes de correo electrónico con comas.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ahorro de receptor ...");
define('VIEW_FORM_TABLES_HEADING', "Ver tablas de formularios");
define('VIEW_FORM_TABLES_BTN', "Ver tablas de formularios");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Seleccione una tabla para ver");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtrar leer mensajes");
?>